;+
; Copyright © 2008, United States Government as represented by the
; Administrator for The National Aeronautics and Space Administration.
; All Rights Reserved.
;
; read_1c21_ppi.pro -- Read 1C21 products and output dbz normal sample data.
;
; AUTHOR:
;       Liang Liao
;       Caelum Research Corp.
;       Code 975, NASA/GSFC
;       Greenbelt, MD 20771
;       Phone: 301-614-5718
;       E-mail: lliao@priam.gsfc.nasa.gov
; MODIFIED:
;       Jul 2008 - Bob Morris, GPM GV (SAIC)
;       - Made into FUNCTION, added HDF_OPEN tests a la load_2b31
;
; EMAIL QUESTIONS OR COMMENTS TO:
;       <Bob Morris> kenneth.r.morris@nasa.gov
;       <Matt Schwaller> mathew.r.schwaller@nasa.gov
;-

; start_sample:  scan number to start reading
; sample_range:  numbers of scans to be read
; num_range:     range number (to be 140 for 1C21)


function read_1c21_ppi, filename, DBZ=dbz_normalSample, GEOL=geolocation, $
                        OCEANFLAG=landOceanFlag, Bins=binS

common sample, start_sample,sample_range,num_range,pw_min

if HDF_IsHDF (filename) then begin
    fileid=hdf_open(filename,/read)
    if ( fileid eq -1 ) then begin
       print, "In read_1c21_ppi.pro, error opening hdf file: ", filename
       flag = 'Bad HDF File!'
       return, flag
    endif
endif else begin
    print, "In read_1c21_ppi.pro, tried to open non-hdf file: ", filename
    flag = 'Not HDF File!'
    return, flag
endelse

sd_id=HDF_SD_START(filename,/read)
HDF_SD_FILEINFO, sd_id, nmfsds, attributes
 ;Display the number of SD type of files
;   print, "# of MFSD = ", nmfsds
   
   if nmfsds gt 0 then begin
;         print,"          Information about MFHDF DataSets "
;         print, ' '
;         print,"  NAME     IDL_Type  HDF_Type       Rank   Dimensions"
;         print,"---------  -------- ----------      ----  ------------"
;         print,"           ------------- Atrribute Info -------------"
;         print
         FSD='(A10,"  ",A8,"  ",I4,"  ",I4)'
         for i=0,nmfsds-1 do begin
          sds_id=HDF_SD_SELECT(sd_id,i)
          HDF_SD_GETINFO,sds_id,name=n,ndims=r,type=t,natts=nats,dims=dims,$
                         hdf_type=h,unit=u,format=fmt,label=label
          if r le 1 then FSD='(A10," ",A8," ",A12,3X,I4,3X,"[",I4,"] ",A)' $
                   else FSD='(A10," ",A8," ",A12,3X,I4,3X,"["'+$
                        STRING(r-1)+'(I5,","),I5,"] ",A)'
          
;          print,n,t,h,r,dims,u,FORMAT=FSD
          if i eq 0 then nsample=dims(2)
;          print 
;         help,n,r,t,nats,dims,u
;         help,fmt,label,range
          HDF_SD_ENDACCESS,sds_id
         endfor
      endif 

; Read data
; Read Normal Sample
;
 
if (START_SAMPLE eq 0) and (SAMPLE_RANGE le 1) then SAMPLE_RANGE=nsample

IF keyword_set(dbz_normalSample) THEN BEGIN

start = [start_sample,0,0]
count = [sample_range,49,num_range]
stride = [1,1,1]

sds_id=HDF_SD_SELECT(sd_id,hdf_sd_nametoindex(sd_id,'normalSample'))
HDF_SD_GETDATA, sds_id, dbz_normalSample, START=start, COUNT=count, $
                STRIDE=stride, /noreverse
                
ENDIF                
; ----------------------                
 
IF keyword_set(geolocation) THEN BEGIN
             
start = [0,0,start_sample]
count = [2,49,sample_range]
stride = [1,1,1]

sds_id=HDF_SD_SELECT(sd_id,hdf_sd_nametoindex(sd_id,'geolocation'))
HDF_SD_GETDATA, sds_id, geolocation, START=start, COUNT=count, $
                STRIDE=stride
ENDIF                 
; -----------------------

IF keyword_set(landOceanFlag) THEN BEGIN

start = [start_sample,0]
count = [sample_range,49]
stride = [1,1]

sds_id=HDF_SD_SELECT(sd_id,hdf_sd_nametoindex(sd_id,'landOceanFlag'))
HDF_SD_GETDATA, sds_id, landOceanFlag, START=start, COUNT=count, $
                STRIDE=stride, /noreverse

ENDIF                 
; ----------------------- 

IF keyword_set(binS) THEN BEGIN

start = [start_sample,0]
count = [sample_range,49]
stride = [1,1]

;sds_id=HDF_SD_SELECT(sd_id,hdf_sd_nametoindex(sd_id,'binSurfPeak'))
sds_id=HDF_SD_SELECT(sd_id,hdf_sd_nametoindex(sd_id,'binEllipsoid'))
HDF_SD_GETDATA, sds_id, binS, START=start, COUNT=count, $
                STRIDE=stride , /noreverse

ENDIF
; -----------------------  

                            
HDF_SD_ENDACCESS,sds_id
HDF_SD_END,sd_id
hdf_close,fileid

flag = 'OK'
return,flag

end
