;+
; Copyright © 2008, United States Government as represented by the
; Administrator for The National Aeronautics and Space Administration.
; All Rights Reserved.
;
; AUTHOR:
;       Liang Liao
;       Caelum Research Corp.
;       Code 975, NASA/GSFC
;       Greenbelt, MD 20771
;       Phone: 301-614-5718
;       E-mail: lliao@priam.gsfc.nasa.gov
;
; EMAIL QUESTIONS OR COMMENTS TO:
;       <Bob Morris> kenneth.r.morris@nasa.gov
;       <Matt Schwaller> mathew.r.schwaller@nasa.gov
;-

pro bias_rain_table, LUN1=lun1, LUN2=lun2, LUN3=lun3, $
                      S_2a25=s_pr, S_2a55=s_gv, $
                      C_2a25=c_pr, C_2a55=c_gv, $
                      T_2a25=t_pr, T_2a55=t_gv, $
                      O_2a25=o_pr, O_2a55=o_gv, $ 
                      L_2a25=l_pr, L_2a55=l_gv, $
                      M_2a25=m_pr, M_2a55=m_gv
                
common time, TRMM_TIME, hh_gv, mm_gv, ss_gv, year, month, day
common nfile_record, nfile
common groundSite, siteLong, siteLat, siteID
common cumulation, s_npt, c_npt, t_npt, o_npt, l_npt, m_npt, $
                   s_pr_tot, s_gv_tot, c_pr_tot, c_gv_tot, $
                   t_pr_tot, t_gv_tot, o_pr_tot, o_gv_tot, $
                   l_pr_tot, l_gv_tot, m_pr_tot, m_gv_tot

rain_min=[0., 5., 10., 15., 20.]
rain_max=[5., 10., 15., 20., 200.]

bias, s_gv, s_pr, BIAS=bias_s, $
      MIN=rain_min, MAX=rain_max, STD_SET=bias_set_s, nPoint_SET=nCount_set_s

bias, c_gv, c_pr, BIAS=bias_c, $
      MIN=rain_min, MAX=rain_max, STD_SET=bias_set_c, nPoint_SET=nCount_set_c

bias, t_gv, t_pr, BIAS=bias_t, $
      MIN=rain_min, MAX=rain_max, STD_SET=bias_set_t, nPoint_SET=nCount_set_t

bias, s_gv_tot[0:(s_npt-1>0)], s_pr_tot[0:(s_npt-1>0)], BIAS=bias_s_tot, $
      MIN=rain_min, MAX=rain_max, STD_SET=bias_set_s_tot, nPoint_SET=nCount_set_tot_s

bias, c_gv_tot[0:(c_npt-1>0)], c_pr_tot[0:(c_npt-1>0)], BIAS=bias_c_tot, $
      MIN=rain_min, MAX=rain_max, STD_SET=bias_set_c_tot, nPoint_SET=nCount_set_tot_c

bias, t_gv_tot[0:(t_npt-1>0)], t_pr_tot[0:(t_npt-1>0)], BIAS=bias_t_tot, $
      MIN=rain_min, MAX=rain_max, STD_SET=bias_set_t_tot, nPoint_SET=nCount_set_tot_t

date=month+'/'+day+'/'+year

zero=""+string(0,format='(i1)')+""
 
if hh_gv lt 10 then hrs_gv = zero+""+string(hh_gv,format='(i1)')+""
if hh_gv ge 10 then hrs_gv = ""+string(hh_gv,format='(i2)')+""

if mm_gv lt 10 then min_gv = zero+""+string(mm_gv,format='(i1)')+""
if mm_gv ge 10 then min_gv = ""+string(mm_gv,format='(i2)')+""

if ss_gv lt 10 then sec_gv = zero+""+string(ss_gv,format='(i1)')+""
if ss_gv ge 10 then sec_gv = ""+string(ss_gv,format='(i2)')+""

gv_time=hrs_gv+':'+min_gv+':'+sec_gv

if nfile eq 0 then begin

  PRINTF, lun1, format='(//)'
  PRINTF, lun1, siteID, $
    format='(4x,6x,"Differences of Mean Rain Rates Derived PR and ",a0," GV")'
  PRINTF, lun1, format='(4x,27x,"for Stratiform")'
  PRINTF, lun1, format='(4x,"______________________________________________________________________")'
  PRINTF, lun1, '  '  &  PRINTF, lun1, '  '
  PRINTF, lun1, format='(6x,3x,4hDATE,7x,"0-5",5x,"5-10",3x,"10-15",3x,"15-20",3x," >20 ",3x," >0 ",5x,"NPT")'
  PRINTF, lun1, format='(6x,1x,"________",4x,"_____",3x,"_____",3x,"_____",3x,"_____",3x,"_____",3x,"_____",3x,"_____")'

  PRINTF, lun2, format='(//)'
  PRINTF, lun2, siteID, $
    format='(4x,6x,"Differences of Mean Rain Rates Derived PR and ",a0," GV")'
  PRINTF, lun2, format='(4x,27x,"for Convective")'
  PRINTF, lun2, format='(4x,"______________________________________________________________________")'
  PRINTF, lun2, '  '  &  PRINTF, lun2, '  '
  PRINTF, lun2, format='(6x,3x,4hDATE,7x,"0-5",5x,"5-10",3x,"10-15",3x,"15-20",3x," >20 ",3x," >0 ",5x,"NPT")'
  PRINTF, lun2, format='(6x,1x,"________",4x,"_____",3x,"_____",3x,"_____",3x,"_____",3x,"_____",3x,"_____",3x,"_____")'

  PRINTF, lun3, format='(//)'
  PRINTF, lun3, siteID, $
    format='(4x,6x,"Differences of Mean Rain Rates Derived PR and ",a0," GV")'
  PRINTF, lun3, format='(4x,27x,"for All Cases")'
  PRINTF, lun3, format='(5x,"_____________________________________________________________________")'
  PRINTF, lun3, '  '  &  PRINTF, lun3, '  '
  PRINTF, lun3, format='(6x,3x,4hDATE,7x,"0-5",5x,"5-10",3x,"10-15",3x,"15-20",3x," >20 ",3x," >0 ",5x,"NPT")'
  PRINTF, lun3, format='(6x,1x,"________",4x,"_____",3x,"_____",3x,"_____",3x,"_____",3x,"_____",3x,"_____",3x,"_____")'

endif

nPoint = SIZE(s_pr,/dimension)  &  if nPoint[0] eq 1 then nPoint[0]=0 
PRINTF, lun1, date, bias_set_s, bias_s, nPoint, $
        format='(6x,1x,a8,3x,6(f6.2,2x),1x,i4)'
PRINTF, lun1, nCount_set_s, $
        format='(6x,1x,8x,4x,5(1x,i4,3x),2x)'        
PRINTF, lun1, ' '

nPoint = SIZE(c_pr,/dimension)  &  if nPoint[0] eq 1 then nPoint[0]=0 
PRINTF, lun2, date, bias_set_c, bias_c, nPoint, $
        format='(6x,1x,a8,3x,6(f6.2,2x),1x,i4)'
PRINTF, lun2, nCount_set_c, $
        format='(6x,1x,8x,4x,5(1x,i4,3x),2x)'        
PRINTF, lun2, ' '

nPoint = SIZE(t_pr,/dimension)  &  if nPoint[0] eq 1 then nPoint[0]=0 
PRINTF, lun3, date, bias_set_t, bias_t, nPoint, $
        format='(6x,1x,a8,3x,6(f6.2,2x),1x,i4)'
PRINTF, lun3, nCount_set_t, $
        format='(6x,1x,8x,4x,5(1x,i4,3x),2x)'        
PRINTF, lun3, ' '
        
total='Total'
if (nfile eq 23) or (nfile eq 44) then begin

      PRINTF, lun1, '  '
      PRINTF, lun1, total, bias_set_s_tot, bias_s_tot, s_npt, $
        format='(6x,2x,a5,5x,6(f6.2,2x),i5)'
      PRINTF, lun1, nCount_set_tot_s, $
        format='(6x,1x,8x,3x,5(1x,i5,2x),2x)'
      PRINTF, lun1, '  '

      PRINTF, lun2, '  '
      PRINTF, lun2, total, bias_set_c_tot, bias_c_tot, c_npt, $
        format='(6x,2x,a5,5x,6(f6.2,2x),i5)'
      PRINTF, lun2, nCount_set_tot_c, $
        format='(6x,1x,8x,3x,5(1x,i5,2x),2x)'
      PRINTF, lun2, '  '

      PRINTF, lun3, '  '
      PRINTF, lun3, total, bias_set_t_tot, bias_t_tot, t_npt, $
        format='(6x,2x,a5,5x,6(f6.2,2x),i5)'
      PRINTF, lun3, nCount_set_tot_t, $
        format='(6x,1x,8x,3x,5(1x,i5,2x),2x)'
      PRINTF, lun3, '  '
      
endif   
        
; -----------------------
        
end
                   
@bias.pro
