;+
; Copyright © 2008, United States Government as represented by the
; Administrator for The National Aeronautics and Space Administration.
; All Rights Reserved.
;
; AUTHOR:
;       Liang Liao
;       Caelum Research Corp.
;       Code 975, NASA/GSFC
;       Greenbelt, MD 20771
;       Phone: 301-614-5718
;       E-mail: lliao@priam.gsfc.nasa.gov
; HISTORY
;       Bob Morris, SAIC, GPM GV
;       Massively rewritten to read from netCDF gridfiles, do any
;       site specified, etc.  Called from doSiteSpecificComparisons.pro in a
;       site-by-site loop.  2A54 Rain Type not available if REORDER is used to
;       create the GV netCDF grids, so we fudge it for now by using a copy of the
;       2A23/2A25 Rain Type.
;
;       Bob Morris, SAIC, GPM GV    March 2008
;       Now calling utility functions read_PR_netcdf(), read_GV_netcdf(), and
;       read_GV_REO_netcdf() to read data/metadata fields from the netCDF files.
;
; It only works for PR v6. 
;
;
; EMAIL QUESTIONS OR COMMENTS TO:
;       <Bob Morris> kenneth.r.morris@nasa.gov
;       <Matt Schwaller> mathew.r.schwaller@nasa.gov
;-

pro comparison_pr_gv_rain, npairs, prfile, gvfile

; "include" file for PR/GV netCDF grid structs, now that we call read_XX_netcdf()
@grid_nc_structs.inc
; instantiate and initialize the structs
mygridstruc={grid_def_meta}
mysitestruc={gv_site_meta}
field_flagsGV = {gv_field_flags}

common sample, start_sample,sample_range,num_range,dbz_min,dbz_max
common sample_rain, RAIN_MIN, RAIN_MAX
common time, TRMM_TIME, hh_gv, mm_gv, ss_gv, year, month, day
common groundSite, siteLong, siteLat, siteID
common cumulation, s_npt, c_npt, t_npt, o_npt, l_npt, m_npt, $
                   s_pr0_tot, s_pr_tot, s_gv_tot, c_pr0_tot, c_pr_tot, c_gv_tot, $
                   t_pr0_tot, t_pr_tot, t_gv_tot, o_pr0_tot, o_pr_tot, o_gv_tot, $
                   l_pr0_tot, l_pr_tot, l_gv_tot, m_pr0_tot, m_pr_tot, m_gv_tot
common nfile_record, nfile

RAIN_MIN = 0.01
RAIN_MAX = 60.



OPENW, lun, "./result/rain_pr_gv"+"."+siteID+".dat", ERROR=err, /GET_LUN 

common PR_GV, rainType_2a23, rainType_2a54, dbz_1c21, dbz_2a25, dbz_2a55, oceanFlag
common PR_GV_RAIN, surfRain_pr, surfRain_gv

dbz_min=0.    ;not in use
dbz_max=0.    ;not in use
 
s_npt = 0L  &  c_npt = 0L  &  t_npt = 0L
s_pr0_tot = fltarr(100000)  &  s_pr_tot = fltarr(100000)  &  s_gv_tot = fltarr(100000)
c_pr0_tot = fltarr(100000)  &  c_pr_tot = fltarr(100000)  &  c_gv_tot = fltarr(100000)
t_pr0_tot = fltarr(100000)  &  t_pr_tot = fltarr(100000)  &  t_gv_tot = fltarr(100000)

o_npt = 0L  &  l_npt = 0L  &  m_npt = 0L
o_pr0_tot = fltarr(100000)  &  o_pr_tot = fltarr(100000)  &  o_gv_tot = fltarr(100000)
l_pr0_tot = fltarr(100000)  &  l_pr_tot = fltarr(100000)  &  l_gv_tot = fltarr(100000)
m_pr0_tot = fltarr(100000)  &  m_pr_tot = fltarr(100000)  &  m_gv_tot = fltarr(100000)

table_0 = "./result/stratiform_mean_std_rain"+"."+siteID+".tab"
table_1 = "./result/convective_mean_std_rain"+"."+siteID+".tab"
table_2 = "./result/total_mean_std_rain"+"."+siteID+".tab"
table_3 = "./result/overOcean_mean_std_rain"+"."+siteID+".tab"
table_4 = "./result/overLand_mean_std_rain"+"."+siteID+".tab"
table_5 = "./result/overMixedWaterLand_mean_std_rain"+"."+siteID+".tab"

;table_6 = "./result/cumulation_stratiform_mean_std_rain"+"."+siteID+".tab"
;table_7 = "./result/cumulation_convective_mean_std_rain"+"."+siteID+".tab"
;table_8 = "./result/cumulation_total_mean_std_rain"+"."+siteID+".tab"
;table_9 = "./result/cumulation_overOcean_mean_std_rain"+"."+siteID+".tab"
;table_10 = "./result/cumulation_overLand_mean_std_rain"+"."+siteID+".tab"
;table_11 = "./result/cumulation_overMixedWaterLand_mean_std_rain"+"."+siteID+".tab"

table_13 = "./result/standardError_rain"+"."+siteID+".tab"
table_14 = "./result/bias_rain_total"+"."+siteID+".tab"
table_15 = "./result/bias_rain_stratiform"+"."+siteID+".tab"
table_16 = "./result/bias_rain_convective"+"."+siteID+".tab"

common lun, lun_0, lun_1, lun_2, lun_3, lun_4, lun_5, lun_6, lun_7, lun_8, lun_9, lun_10, lun_11

OPENW, lun_0, table_0, ERROR=err, /GET_LUN
OPENW, lun_1, table_1, ERROR=err, /GET_LUN
OPENW, lun_2, table_2, ERROR=err, /GET_LUN
OPENW, lun_3, table_3, ERROR=err, /GET_LUN
OPENW, lun_4, table_4, ERROR=err, /GET_LUN
OPENW, lun_5, table_5, ERROR=err, /GET_LUN
;OPENW, lun_6, table_6, ERROR=err, /GET_LUN
;OPENW, lun_7, table_7, ERROR=err, /GET_LUN
;OPENW, lun_8, table_8, ERROR=err, /GET_LUN
;OPENW, lun_9, table_9, ERROR=err, /GET_LUN
;OPENW, lun_10, table_10, ERROR=err, /GET_LUN
;OPENW, lun_11, table_11, ERROR=err, /GET_LUN

OPENW, lun_13, table_13, ERROR=err, /GET_LUN
OPENW, lun_14, table_14, ERROR=err, /GET_LUN
OPENW, lun_15, table_15, ERROR=err, /GET_LUN
OPENW, lun_16, table_16, ERROR=err, /GET_LUN

nfile=-1

for i=0, npairs-1 do begin

;  LOOP OVER EACH SITE'S FILES.  SKIP IF NO GV DATA FILE
   if (gvfile[i] eq 'no_GV_file') then begin
      print, "Skipping - No GV file for PR file ", prfile[i]
      CONTINUE
   endif
   nfile = nfile + 1                      ; for common block

;  get unzipped copy of the netCDF file pair in current working directory
   flag = uncomp_file(prfile[i],prfile_2do)
   if(flag ne 'OK') then begin
       print,flag
       stop
       CONTINUE
   endif

   flag = uncomp_file(gvfile[i],gvfile_2do)
   if(flag ne 'OK') then begin
       print,flag
       stop
       CONTINUE
   endif

; READ DATA AND DO rain rate COMPARISON

   status = 1       ; initialize to FAILED
   event_time=0.0D
   mygrid=mygridstruc
   mysite=mysitestruc
   dbzcor=fltarr(2)
   dbzraw=fltarr(2)
   surfRain_pr=fltarr(2)
   oceanFlag=intarr(2)
   rainType_2a23=intarr(2)
   status = read_pr_netcdf( prfile_2do, dtime=event_time, gridmeta=mygrid, $
       sitemeta=mysite, dbzraw3d=dbzraw, dbz3d=dbzcor, sfcrain2d=surfRain_pr, $
       sfctype2d_int=oceanFlag, raintype2d_int=rainType_2a23 )
   command = "rm  " + prfile_2do
   spawn, command
   IF (status NE 0) THEN BEGIN
     print, "ERROR in reading PR netCDF file: ", prfile_2do
     command = "rm " + gvfile_2do
     spawn, command
     CONTINUE
   ENDIF
   siteLat = mysite.site_lat
   siteLong = mysite.site_lon

; query 2A-5x netCDF file variables
   status = 1       ; initialize to FAILED
   event_time2=0.0D
   mygrid=mygridstruc
   mysite=mysitestruc
   myfieldflags=field_flagsGV
   dbznex=fltarr(2)
   rainType_2a54=intarr(2)
   surfRain_gv=fltarr(2)

; check for GV netCDF file type via name convention: *_REO* => REORDER
   gvreo = STRPOS( gvfile[i], "_REO" )
   if (gvreo ne -1) then begin
; no rainrate field in REORDER netCDF file variables, report error
     print, "ERROR, can't use GV REORDER netCDF file: ", gvfile_2do
     command = "rm  " + gvfile_2do
     spawn, command
     CONTINUE
   endif else begin
; query 2A-5x netCDF file variables
     status = read_gv_netcdf( gvfile_2do, dtime=event_time2, gridmeta=mygrid, $
         sitemeta=mysite, fieldflagsGV=myfieldflags, dbz3d=dbznex, $
         sfcrain2d=surfRain_gv, raintype2d_int=rainType_2a54 )
     command = "rm  " + gvfile_2do
     spawn, command
     IF (status NE 0) THEN BEGIN
       print, "ERROR in reading GV netCDF file: ", gvfile_2do
       CONTINUE
     ENDIF
   endelse

print, 'have_threeDreflect = ', myfieldflags.have_threeDreflect
print, 'have_convStratFlag = ', myfieldflags.have_convStratFlag
print, 'have_rainRate = ', myfieldflags.have_rainRate


;   scale the oceanFlag as commonArea expects
   oceanFlag = oceanFlag * 10

   TRMM_DATETIME = SYSTIME(0, event_time, /UTC)  ; e.g., Thu Jan  1 00:01:00 1970
   timeparts=strsplit(TRMM_DATETIME, '  *', /extract)
   TRMM_TIME=timeparts[3]                    ; i.e., the HH:MM:SS field
   NEXRAD_TIME = SYSTIME(0, event_time2, /UTC)
   unix2datetime, event_time2, yearN, monthN, dayN, hh_gv, mm_gv, ss_gv
   year = STRING(yearN-((yearN/100)*100), FORMAT='(i02)')
   month = STRING(monthN, FORMAT='(i02)')
   day = STRING(dayN, FORMAT='(i02)')

;  Need to include groundSite common in, or pass in siteID to, these
;  bad boys so that the headings in the products are not hard-wired
;  to Melbourne FL.

   
   commonArea_rain,  S_2a25=s_pr, S_2a55=s_gv, $
                     C_2a25=c_pr, C_2a55=c_gv, $
                     T_2a25=t_pr, T_2a55=t_gv, $
                     O_2a25=o_pr, O_2a55=o_gv, $ 
                     L_2a25=l_pr, L_2a55=l_gv, $
                     M_2a25=m_pr, M_2a55=m_gv 
               
   statistics_rain_table,   $
                           S_2a25=s_pr, S_2a55=s_gv, $
                           C_2a25=c_pr, C_2a55=c_gv, $
                           T_2a25=t_pr, T_2a55=t_gv, $
                           O_2a25=o_pr, O_2a55=o_gv, $ 
                           L_2a25=l_pr, L_2a55=l_gv, $
                           M_2a25=m_pr, M_2a55=m_gv
                                                                  
   bias_rain_table, LUN1=lun_15, LUN2=lun_16, LUN3=lun_14, $
                      S_2a25=s_pr, S_2a55=s_gv, $
                      C_2a25=c_pr, C_2a55=c_gv, $
                      T_2a25=t_pr, T_2a55=t_gv, $
                      O_2a25=o_pr, O_2a55=o_gv, $ 
                      L_2a25=l_pr, L_2a55=l_gv, $
                      M_2a25=m_pr, M_2a55=m_gv
                      
   standardError_rain_table, LUN=lun_13,  $
                      S_2a25=s_pr, S_2a55=s_gv, $
                      C_2a25=c_pr, C_2a55=c_gv, $
                      T_2a25=t_pr, T_2a55=t_gv, $
                      O_2a25=o_pr, O_2a55=o_gv, $ 
                      L_2a25=l_pr, L_2a55=l_gv, $
                      M_2a25=m_pr, M_2a55=m_gv                   
   
   mean_std, t_pr, MEAN=mean_t_pr, STD=std_t_pr
   mean_std, t_gv, MEAN=mean_t_gv, STD=std_t_gv                   
   nPoint = n_elements(t_pr) 
   PRINTF, lun, mean_t_pr, mean_t_gv, nPoint
   
EndFor

plot_scaPoint_rain, "rainSca"+"."+siteID+".ps"
plot_histogram_rain, "rain_histogram"+"."+siteID+".ps"

;CLOSE, lun0  &   FREE_LUN, lun0
;CLOSE, lun1  &   FREE_LUN, lun1
;CLOSE, lun2  &   FREE_LUN, lun2
;CLOSE, lun3  &   FREE_LUN, lun3
;CLOSE, lun4  &   FREE_LUN, lun4
CLOSE, lun_0  &   FREE_LUN, lun_0
CLOSE, lun_1  &   FREE_LUN, lun_1
CLOSE, lun_2  &   FREE_LUN, lun_2
CLOSE, lun_3  &   FREE_LUN, lun_3
CLOSE, lun_4  &   FREE_LUN, lun_4
CLOSE, lun_5  &   FREE_LUN, lun_5
;CLOSE, lun_6  &   FREE_LUN, lun_6
;CLOSE, lun_7  &   FREE_LUN, lun_7
;CLOSE, lun_8  &   FREE_LUN, lun_8
;CLOSE, lun_9  &   FREE_LUN, lun_9
;CLOSE, lun_10  &   FREE_LUN, lun_10
;CLOSE, lun_11  &   FREE_LUN, lun_11
CLOSE, lun_13  &   FREE_LUN, lun_13
CLOSE, lun_14  &   FREE_LUN, lun_14
CLOSE, lun_15  &   FREE_LUN, lun_15
CLOSE, lun_16  &   FREE_LUN, lun_16
CLOSE, lun     &   FREE_LUN, lun 

end

@commonArea_rain.pro
@plot_scaPoint_rain.pro
@plot_histogram_rain.pro
@statistics_rain_table.pro
@standardError_rain_table.pro
@bias_rain_table.pro
